import { DirectoryInfo, FileFilterFn, FileInfo, FileOrDirectoryInfo, IDirectoryData, IDirectoryStore, IDirectoryStoreOptions } from "./types";
interface FileSystemAccessProps {
    filters?: FileFilterFn[];
    store?: IDirectoryStore<IDirectoryData, IDirectoryStoreOptions>;
    enableFileWatcher?: boolean;
    fileWatcherOptions?: FileWatcherOptions;
    onFilesAdded?: (newEntries: Map<string, FileOrDirectoryInfo>) => void;
    onFilesDeleted?: (deletedEntries: Map<string, FileOrDirectoryInfo>) => void;
    onFilesModified?: (modifiedFiles: Map<string, FileInfo>) => void;
}
export interface OpenDirectoryOptions extends DirectoryPickerOptions {
    save?: boolean;
    saveOptions?: IDirectoryStoreOptions;
    directory?: FileSystemDirectoryHandle;
}
export interface WriteFileOptions {
    create?: boolean;
    open?: boolean;
    keepData?: boolean;
}
export interface FileWatcherOptions {
    pollInterval?: number;
    cacheTime?: number;
    batchSize?: number;
    debug?: boolean;
}
export default function useFileSystemAccess(props?: FileSystemAccessProps): {
    isSupported: boolean;
    files: Map<string, FileOrDirectoryInfo>;
    pending: boolean;
    openDirectory: (options?: OpenDirectoryOptions) => Promise<void>;
    expandDirectory: (path: string) => Promise<void>;
    openFile: (path: string) => Promise<FileInfo>;
    closeFile: (path: string) => Promise<FileInfo>;
    writeFile: (path: string, options?: WriteFileOptions, data?: string | Blob | ArrayBuffer) => Promise<FileInfo>;
    createDirectory: (name: string, parentPath: string) => Promise<DirectoryInfo>;
    deleteFile: (path: string) => Promise<void>;
    deleteDirectory: (path: string, recursive?: boolean) => Promise<void>;
    directoryAccessor: {
        getSavedDirectories: (providerOptions?: IDirectoryStoreOptions) => Promise<Map<string, FileSystemDirectoryHandle>>;
        clearSavedDirectories: (providerOptions?: IDirectoryStoreOptions) => Promise<void>;
        removeSavedDirectory: (directoryName: string, providerOptions?: IDirectoryStoreOptions) => Promise<void>;
    };
};
export {};
